Naked  [![PyPI version](https://badge.fury.io/py/Naked.png)](https://pypi.python.org/pypi/Naked)
=====
Naked is a MIT licensed Python command line application framework that is in
development.  The current release is an early stable testing version.  If you
use the libraries at this stage, please watch for changes.  Things may break...

It features:

(1) an executable that supports simple Python project generation, testing,
profiling, and distribution to PyPI.

(2) a Python library with an easy to use command line string object parser and
numerous Python type/method/function extensions.

• **Main Project Site**: [http://naked.readthedocs.io/](http://naked.readthedocs.io/)

• **QuickStart Guide**:
[http://naked.readthedocs.io/quickstart.html](http://naked.readthedocs.io/quickstart.html).
It demonstrates how the available tools can be incorporated into your
development workflow, spanning the entire period from an empty project
directory to your first PyPI version release.

• **Documentation**:
[http://naked.readthedocs.io](http://naked.readthedocs.io/)

• Contributions to the source and feedback are definitely welcomed!  Please
submit any bug reports with the GitHub issue tracker.

